Test Command Error
open | ../tests/html/test_verifications.html |
verifyErrorOnNext | Element notALink not found |
click | notALink |
verifyErrorOnNext | Element noSuchSelect not found |
select | noSuchSelect | somelabel
verifyErrorOnNext | Option with label 'noSuchLabel' not found |
select | theSelect | label=noSuchLabel
verifyErrorOnNext | Specified element is not a Select (has no options) |
select | theText | label=noSuchLabel